Method: Packet_List#add_header

Defined in:
lib/Packet_List.rb

#add_header(text, width, &conversion) ⇒ Object

Add a new header. The block that you need to specify is used to convert a string of this column into something that can be used for sorting. The yielded parameter item_colum_text is the text of one item of this column.



94
95
96
97
98
# File 'lib/Packet_List.rb', line 94

def add_header(text, width, &conversion) # :yields: item_column_text
  appendHeader(text, nil, width)
  header.setArrowDir(0, false) if @conversions.empty?
  @conversions.push conversion
end