Method: Packet_List#getContentHeight

Defined in:
lib/Packet_List.rb

#getContentHeight(*args) ⇒ Object

This may be called when the item is currently beeing deleted. this method works only before or after the delete, therefore the mutex is necessary.



166
167
168
169
170
171
# File 'lib/Packet_List.rb', line 166

def getContentHeight(*args)
  $fx_icon_item_remove_mutex.synchronize do
    #puts "contentheight"
    super
  end
end