Method: Packet_List#getContentWidth

Defined in:
lib/Packet_List.rb

#getContentWidth(*args) ⇒ Object

This may be called when the item is currently beeing deleted. this method works only before or after the delete, therefore the mutex is necessary.



156
157
158
159
160
161
# File 'lib/Packet_List.rb', line 156

def getContentWidth(*args)
  $fx_icon_item_remove_mutex.synchronize do
    #puts "contentwidth"
    super
  end
end