Method: Packet_List#removeItem
- Defined in:
- lib/Packet_List.rb
#removeItem(*args) ⇒ Object
Before actually deleting, the item has to be marked as deleted to prevent drawing afterwards.
135 136 137 138 139 140 141 142 143 |
# File 'lib/Packet_List.rb', line 135 def removeItem(*args) $fx_icon_item_remove_mutex.synchronize do #puts "removeitem" # at first, mark item as deleted to prevent drawing afterwards getItem(args[0]).deleted # do the evil delete super end end |